---
title: 'Maintaining'
hide:
    - footer
---

Maintaining a project is distinct from contributing to a project. A maintainer merges PRs and manages issues and discussions. Some of these tasks need to be documented so that things are done appropriately, consistently, and transparently.

Currently, there is only one maintainer of this project. I will be looking to build a small group of maintainers, as my long-term goal is that this project belongs to the community. A maintainer needs to  understand the technical tasks of merging PRs and managing issues, but also needs to be really clear about discussing, navigating, and defining the boundaries of this project.

Also, I know that Python packaging is often criticized as confusing because many different approaches have been tried over the years. I want to be clear about the processes used for developing and maintaining this package. If you are experienced in Python package management and have critical feedback about the processes you see here, please feel free to share your thoughts.